@@ -21,16 +21,11 @@
 #ifndef _TDEPOWERSAVE_DEBUG_H
 #define _TDEPOWERSAVE_DEBUG_H
 
-// Global Header
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // Default Header
 #include <stdio.h>
 #include <stdlib.h>
 
-// QT - Header
+// TQt - Header
 #include <tqdatetime.h>
 
 // KDE Header
